@@ -1204,7 +1204,7 @@ static gpg_error_t save_command_finalize(assuan_context_t ctx, guchar *key,
 	gcry_free(client->crypto->key);
 
     client->crypto->key = key;
-    rc = update_timestamp(client->doc);
+    rc = update_element_mtime(xmlDocGetRootElement(client->doc));
 
     if (rc)
 	return send_error(ctx, rc);
@@ -1442,13 +1442,20 @@ static gint delete_command(assuan_context_t ctx, gchar *line)
      * No sub-node defined. Remove the entire node (root element).
      */
     if (!req[1]) {
+	xmlNodePtr parent = n->parent;
+
 	if (n) {
 	    xmlUnlinkNode(n);
 	    xmlFreeNode(n);
 	}
 
 	g_strfreev(req);
-	return send_error(ctx, 0);
+	rc = 0;
+
+	if (parent)
+	    rc = update_element_mtime(parent);
+
+	return send_error(ctx, rc);
     }
 
     n = find_elements(client->doc, n->children, req+1, &rc, NULL, NULL, NULL, FALSE, 0, NULL, FALSE);
@@ -1458,11 +1465,17 @@ static gint delete_command(assuan_context_t ctx, gchar *line)
 	return send_error(ctx, rc);
 
     if (n) {
+	xmlNodePtr parent = n->parent;
+
 	xmlUnlinkNode(n);
 	xmlFreeNode(n);
+	rc = 0;
+
+	if (parent)
+	    rc = update_element_mtime(parent);
     }
 
-    return send_error(ctx, 0);
+    return send_error(ctx, rc);
 }
 
 /*
@@ -1512,14 +1525,18 @@ again:
 
     if (req[1]) {
 	if (!n->children)
-	    create_elements_cb(n, req+1, &rc, NULL);
+	    n = create_elements_cb(n, req+1, &rc, NULL);
 	else
-	    find_elements(client->doc, n->children, req+1, &rc,
+	    n = find_elements(client->doc, n->children, req+1, &rc,
 		    NULL, NULL, create_elements_cb, FALSE, 0, NULL, FALSE);
     }
 
     g_strfreev(req);
     client->inquire_status = INQUIRE_DONE;
+
+    if (!rc)
+	rc = update_element_mtime(n);
+
     return rc;
 }
 
@@ -1930,7 +1947,7 @@ fail:
 /*
  * req[0] - element path
  */
-static gint attribute_list(assuan_context_t ctx, gchar **req)
+static gpg_error_t attribute_list(assuan_context_t ctx, gchar **req)
 {
     struct client_s *client = assuan_get_pointer(ctx);
     gchar **attrlist = NULL;
@@ -2019,7 +2036,7 @@ static gint attribute_list(assuan_context_t ctx, gchar **req)
  * req[0] - attribute
  * req[1] - element path
  */
-static gint attribute_delete(struct client_s *client, gchar **req)
+static gpg_error_t attribute_delete(struct client_s *client, gchar **req)
 {
     xmlNodePtr n;
     gchar **path = NULL;
@@ -2058,8 +2075,7 @@ static gint attribute_delete(struct client_s *client, gchar **req)
 	    goto fail;
     }
 
-    g_strfreev(path);
-    return delete_attribute(n, (xmlChar *)req[0]);
+    rc = delete_attribute(n, (xmlChar *)req[0]);
 
 fail:
     g_strfreev(path);
@@ -2287,7 +2303,7 @@ static gpg_error_t name_attribute(struct client_s *client, gchar **req)
  * req[0] - attribute
  * req[1] - element path
  */
-static gint attribute_get(assuan_context_t ctx, gchar **req)
+static gpg_error_t attribute_get(assuan_context_t ctx, gchar **req)
 {
     struct client_s *client = assuan_get_pointer(ctx);
     xmlNodePtr n;
@@ -2345,7 +2361,7 @@ fail:
  * req[1] - element path
  * req[2] - value
  */
-static gint attribute_set(struct client_s *client, gchar **req)
+static gpg_error_t attribute_set(struct client_s *client, gchar **req)
 {
     gchar **path = NULL;
     gpg_error_t rc;
@@ -2389,8 +2405,7 @@ static gint attribute_set(struct client_s *client, gchar **req)
 	    goto fail;
     }
 
-    g_strfreev(path);
-    return add_attribute(n, req[0], req[2]);
+    rc = add_attribute(n, req[0], req[2]);
 
 fail:
     g_strfreev(path);
