@@ -569,7 +569,7 @@ gpg_error_t lock_pin_mutex(struct client_s *client)
 {
     gpg_error_t rc = 0;
 
-    MUTEX_TRYLOCK(client->ctx, &pin_mutex, rc);
+    MUTEX_TRYLOCK(client, &pin_mutex, rc);
 
     if (!rc)
 	client->pinentry->has_lock = TRUE;
