@@ -424,7 +424,8 @@ static gboolean new_connection(struct client_s *cl)
 
     rc = validate_peer(cl);
 
-    if (rc)
+    /* May not be implemented on all platforms. */
+    if (rc && gpg_err_code(rc) != GPG_ERR_ASS_GENERAL)
 	goto fail;
 
     str = get_key_file_string("global", "debug_file");
