@@ -25,16 +25,6 @@
 
 #define PWMD_ERR_SOURCE		GPG_ERR_SOURCE_USER_1
 
-#define EPWMD_BADKEY		GPG_ERR_INV_PASSPHRASE
-#define EPWMD_COMMAND_SYNTAX	GPG_ERR_SYNTAX
-#define EPWMD_ELEMENT_NOT_FOUND	GPG_ERR_ELEMENT_NOT_FOUND
-#define EPWMD_CACHE_NOT_FOUND	GPG_ERR_NOT_FOUND
-#define EPWMD_ATTR_SYNTAX	GPG_ERR_SYNTAX
-#define EPWMD_ATTR_NOT_FOUND	GPG_ERR_NOT_FOUND
-#define EPWMD_INVALID_FILENAME	GPG_ERR_INV_VALUE
-#define EPWMD_EMPTY_ELEMENT	GPG_ERR_NO_VALUE
-#define EPWMD_INVALID_ELEMENT	GPG_ERR_INV_VALUE
-#define EPWMD_LOOP		GPG_ERR_ELOOP
 #define EPWMD_NO_FILE		GPG_ERR_USER_1
 #define EPWMD_LIBXML_ERROR	GPG_ERR_USER_2
 #define EPWMD_FILE_MODIFIED	GPG_ERR_USER_3
