@@ -892,28 +892,18 @@ children:
 gpg_error_t add_attribute(xmlNodePtr node, const gchar *name,
 	const gchar *value)
 {
-    xmlAttrPtr a;
-
-    if ((a = xmlHasProp(node, (xmlChar *)name)) == NULL) {
-	a = xmlNewProp(node, (xmlChar *)name, (xmlChar *)value);
-
-	if (!a)
-	    return EPWMD_LIBXML_ERROR;
-    }
-    else
-	xmlNodeSetContent(a->children, (xmlChar *)value);
-
-    return 0;
-}
-
-gpg_error_t update_timestamp(xmlDocPtr doc)
-{
-    xmlNodePtr n = xmlDocGetRootElement(doc);
-    gchar *t = g_strdup_printf("%li", time(NULL));
+    gchar *buf;
     gpg_error_t rc;
 
-    rc = add_attribute(n, "age", t);
-    g_free(t);
+    if (name && !xmlSetProp(node, (xmlChar *)name, (xmlChar *)value))
+	return EPWMD_LIBXML_ERROR;
+
+    if (name && xmlStrEqual((xmlChar *)name, (xmlChar *)"_mtime"))
+	return 0;
+
+    buf = g_strdup_printf("%li", time(NULL));
+    rc = add_attribute(node, "_mtime", buf);
+    g_free(buf);
     return rc;
 }
 
@@ -1021,6 +1011,7 @@ gpg_error_t recurse_xpath_nodeset(xmlDocPtr doc, xmlNodeSetPtr nodes,
 
     for (; value ? i >= 0 : i < nodes->nodeNr; value ? i-- : i++) {
 	xmlNodePtr n = nodes->nodeTab[i];
+	gpg_error_t rc;
 
 	if (!n)
 	    continue;
@@ -1034,11 +1025,14 @@ gpg_error_t recurse_xpath_nodeset(xmlDocPtr doc, xmlNodeSetPtr nodes,
 	    continue;  
 	}
 
-	if (!attr)
+	if (!attr) {
 	    xmlNodeSetContent(n, value);
+	    rc = update_element_mtime(n);
+
+	    if (rc)
+		return rc;
+	}
 	else {
-	    gpg_error_t rc;
-	    
 	    if (!cmd)
 		rc = add_attribute(n, (gchar *)attr, (gchar *)value);
 	    else
@@ -1144,7 +1138,7 @@ gpg_error_t delete_attribute(xmlNodePtr n, const xmlChar *name)
     if (xmlRemoveProp(a) == -1)
 	return EPWMD_LIBXML_ERROR;
 
-    return 0;
+    return update_element_mtime(n);
 }
 
 static gpg_error_t convert_elements_recurse(xmlDocPtr doc, xmlNodePtr n,
@@ -1277,3 +1271,8 @@ gpg_error_t validate_import(xmlNodePtr node)
 
     return rc;
 }
+
+gpg_error_t update_element_mtime(xmlNodePtr n)
+{
+    return add_attribute(n, NULL, NULL);
+}
